==> nextcloud-12.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/sl.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Dejavnosti",
    "An error occurred while loading activities" : "Pri nalaganju dejavnosti je prišlo do napake",
    "No activity yet" : "Ni zabeležene dejavnosti",
    "Load more activities" : "Naloži več dejavnosti",
    "Copied!" : "Kopirano!",
    "Not supported!" : "Ni podprto!",
    "Press ⌘-C to copy." : "Pritisni ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisni Ctrl-C za kopiranje",
    "{name} (invisible)" : "{name} (nevidno)",
    "{name} (restricted)" : "{name} (omejeno)",
    "in {path}" : "v {path}",
    "This stream will show events like additions, changes & shares" : "V tem pretoku bodo pokazani dogodki, kot so dodajanja, spremembe in spreminjanje souporabe.",
    "There are no events for this filter" : "Ta filter ne pokaže nobenih dogodkov",
    "Today" : "Danes",
    "Yesterday" : "Včeraj",
    "Personal activity feed for %s" : "Osebne dejavnosti za %s",
    "Your feed URL is invalid" : "Spletni naslov vira ni veljaven",
    "Your settings have been updated." : "Nastavitve so posodobljene.",
    "Settings have been updated." : "Nastavitve so bile spremenjene.",
    "Mail" : "Elektronska pošta",
    "Stream" : "Pretok",
    "All activities" : "Vse dejavnosti",
    "By others" : "Od drugih",
    "By you" : "Tvoje",
    "\"remote user\"" : "\"oddaljeni uporabnik\"",
    "Hello %s" : "Pozdravljeni, %s,",
    "Hello %s," : "Pozdravljeni, %s,",
    "There was some activity at %s" : "Bilo je nekaj dejavosti ob %s",
    "_and %n more _::_and %n more _" : ["- in še %n","- in še %n","- in še %n","- in še %n"],
    "Activity notification" : "Obvestila o dejavnosti",
    ", " : ",",
    "%s and %s" : "%s in %s",
    "Activity" : "Dejavnosti",
    "Activity feed" : "Objava dejavnosti z viri RSS",
    "Configure the default activity settings for new users." : "Prevzete nastavitve aktivnosti za nove uporabnike.",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Izberite, za katere dejavnosti želite, da dobite e-poštno obvestilo.",
    "List your own actions in the stream" : "Izpiši seznam opravil v pretoku",
    "Notify about your own actions via email" : "O mojih dejanjih me obvesti preko elektronske pošte",
    "You need to set up your email address before you can receive notification emails." : "Za prejemanje obvestil prek elektronske pošte je treba najprej nastaviti elektronski poštni naslov.",
    "Send emails:" : "Pošlji elektronsko sporočilo:",
    "Hourly" : "Vsako uro",
    "Daily" : "Dnevno",
    "Weekly" : "Tedensko",
    "Settings" : "Nastavitve",
    "Enable RSS feed" : "Omogoči vire RSS",
    "No more events to load" : "Ni več dogodkov za nalaganje",
    "Files" : "Datoteke",
    "Error loading activities" : "Napaka pri nalaganju dejavnosti",
    "No activities" : "Ni dejavnosti"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/sl.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Dejavnosti",
    "An error occurred while loading activities" : "Pri nalaganju dejavnosti je prišlo do napake",
    "No activity yet" : "Ni zabeležene dejavnosti",
    "Load more activities" : "Naloži več dejavnosti",
    "Copied!" : "Kopirano!",
    "Not supported!" : "Ni podprto!",
    "Press ⌘-C to copy." : "Pritisni ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisni Ctrl-C za kopiranje",
    "{name} (invisible)" : "{name} (nevidno)",
    "{name} (restricted)" : "{name} (omejeno)",
    "in {path}" : "v {path}",
    "This stream will show events like additions, changes & shares" : "V tem pretoku bodo pokazani dogodki, kot so dodajanja, spremembe in spreminjanje souporabe.",
    "There are no events for this filter" : "Ta filter ne pokaže nobenih dogodkov",
    "Today" : "Danes",
    "Yesterday" : "Včeraj",
    "Personal activity feed for %s" : "Osebne dejavnosti za %s",
    "Your feed URL is invalid" : "Spletni naslov vira ni veljaven",
    "Your settings have been updated." : "Nastavitve so posodobljene.",
    "Settings have been updated." : "Nastavitve so bile spremenjene.",
    "Mail" : "Elektronska pošta",
    "Stream" : "Pretok",
    "All activities" : "Vse dejavnosti",
    "By others" : "Od drugih",
    "By you" : "Tvoje",
    "\"remote user\"" : "\"oddaljeni uporabnik\"",
    "Hello %s" : "Pozdravljeni, %s,",
    "Hello %s," : "Pozdravljeni, %s,",
    "There was some activity at %s" : "Bilo je nekaj dejavosti ob %s",
    "_and %n more _::_and %n more _" : ["- in še %n","- in še %n","- in še %n","- in še %n"],
    "Activity notification" : "Obvestila o dejavnosti",
    ", " : ",",
    "%s and %s" : "%s in %s",
    "Activity" : "Dejavnosti",
    "Activity feed" : "Objava dejavnosti z viri RSS",
    "Configure the default activity settings for new users." : "Prevzete nastavitve aktivnosti za nove uporabnike.",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Izberite, za katere dejavnosti želite, da dobite e-poštno obvestilo.",
    "List your own actions in the stream" : "Izpiši seznam opravil v pretoku",
    "Notify about your own actions via email" : "O mojih dejanjih me obvesti preko elektronske pošte",
    "You need to set up your email address before you can receive notification emails." : "Za prejemanje obvestil prek elektronske pošte je treba najprej nastaviti elektronski poštni naslov.",
    "Send emails:" : "Pošlji elektronsko sporočilo:",
    "Hourly" : "Vsako uro",
    "Daily" : "Dnevno",
    "Weekly" : "Tedensko",
    "Settings" : "Nastavitve",
    "Enable RSS feed" : "Omogoči vire RSS",
    "No more events to load" : "Ni več dogodkov za nalaganje",
    "Files" : "Datoteke",
    "Error loading activities" : "Napaka pri nalaganju dejavnosti",
    "No activities" : "Ni dejavnosti",
    "You are receiving this email because the following things happened at %s" : "To sporočilo ste prejeli, ker so se zgodili naslednji dogodki na %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* in %n dodaten","* in %n dodatna","* in %n dodatnih","* in %n dodatnih"]
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
